
from __future__ import annotations
from typing import Union
from .utils.one_of_base_model import OneOfBaseModel
from .execution_connector_simple_expression import ExecutionConnectorSimpleExpression
from .execution_connector_grouping_expression import (
    ExecutionConnectorGroupingExpression,
)


class ExecutionConnectorExpressionGuard(OneOfBaseModel):
    class_list = {
        "ExecutionConnectorSimpleExpression": ExecutionConnectorSimpleExpression,
        "ExecutionConnectorGroupingExpression": ExecutionConnectorGroupingExpression,
    }


ExecutionConnectorExpression = Union[
    ExecutionConnectorSimpleExpression, ExecutionConnectorGroupingExpression
]
